@@ -1,7 +1,7 @@
 # Imagekit options
 from imagekit import processors
 from imagekit.specs import ImageSpec
-    
+
 
 class Options(object):
     """ Class handling per-model imagekit options
@@ -13,11 +13,14 @@ class Options(object):
     preprocessor_spec = None
     cache_dir = 'cache'
     save_count_as = None
+    cache_filename_fields = ['pk', ]
     cache_filename_format = "%(filename)s_%(specname)s.%(extension)s"
     admin_thumbnail_spec = 'admin_thumbnail'
     spec_module = 'imagekit.defaults'
-    
-    def __init__(self, opts):        
+    specs = None
+    #storage = defaults to image_field.storage
+
+    def __init__(self, opts):
         for key, value in opts.__dict__.iteritems():
             setattr(self, key, value)
-            self.specs = []
\ No newline at end of file
+        self.specs = list(self.specs or [])
